API reference
=============

``naif``
--------

.. autofunction:: naif.find_peak_freqs

.. autofunction:: naif.chi_p

.. autofunction:: naif.mn_phi_om

.. autofunction:: naif._base_funcs.inner_prod

.. autofunction:: naif._base_funcs.gs
